@@ -99,6 +99,10 @@ class MapFunctions(object):
             zs.append(co.C)
             vs.append(va)                        
         return xs,ys,zs,vs
+    
+    def get_map_cross_section(self, sliced,layer):
+        vals = self.interper.get_cross_section(sliced.lower(),layer)        
+        return vals
 
         
 
